@@ -192,7 +192,7 @@ class SDM:
             records = worksheet.get_all_records()
             if delete:
                 spreadsheet.del_worksheet(worksheet)
-            return records
+            return records[1:]
         except APIError as e:
             error_message = str(e)
             if re.search(r"Sheet with name: .* not found", error_message):
@@ -290,6 +290,7 @@ class SDM:
 
         train_data = []
         test_data = []
+
         if generated_data:
             generated_data_dfs = pd.DataFrame(generated_data,
                                               columns=self.column_names)
@@ -297,12 +298,22 @@ class SDM:
             train_data, test_data = train_test_split.split(
                 generated_data_dfs, test_ratio=test_ratio
             )
+        log.debug("current training data %d items.",
+                  len(current_training_data))
+        log.debug("Generated data %d items.", len(train_data))
+        log.debug(current_training_data[0])
+        log.debug(train_data[0])
 
         total_train_data = pd.DataFrame(train_data + current_training_data,
                                         columns=self.column_names)
         total_test_data = pd.DataFrame(test_data + current_testing_data,
                                        columns=self.column_names)
 
+        log.debug("total training data %d.", len(total_train_data))
+        log.debug("%s", total_train_data.iloc[0])
+        log.debug("%s", total_train_data.iloc[100])
+        log.debug("%s", total_train_data.iloc[1000])
+
         self.add_new_data_to_local_dataset(total_train_data, language, "train")
         self.add_new_data_to_local_dataset(total_test_data, language, "test")
 
